/* Author: Derek O Reilly, Dundalk Institute of Technology, Ireland. */

class Bullseye extends StaticImage
{
    /* Each gameObject MUST have a constructor() and a render() method.        */
    /* If the object animates, then it must also have an updateState() method. */

    constructor(image, x, y, width, height)
    {
        super(image, x, y, width, height); /* as this class extends from GameObject, you must always call super() */

        /* These variables depend on the object */
        this.image = image;
        this.width = width;
        this.height = height;
        this.x = x;
        this.y = y;
        
        this.bullseyeSize = 10; // the granularity of the bullseye target.
    }

    getX()
    {
        return this.x;
    }

    getY()
    {
        return this.y;
    }

    getWidth()
    {
        return this.width;
    }

    getHeight()
    {
        return this.height;
    }

    pointIsInsideBullseyeRectangle(pointX, pointY)
    {
        /* The bullseye is set to have a width and height of bullseySize */
        /* The bulleseye is set from the centre of the bullseye image    */
        
        let bullseyeX = this.x + ((this.width - this.bullseyeSize) / 2);
        let bullseyeY = this.y + ((this.height - this.bullseyeSize) / 2);  

        if ((pointX > bullseyeX) && (pointY > bullseyeY))
        {
            if (pointX > bullseyeX)
            {
                if ((pointX - bullseyeX) > this.bullseyeSize)
                {
                    return false; // to the right of this gameObject
                }
            }

            if (pointY > bullseyeY)
            {
                if ((pointY - bullseyeY) > this.bullseyeSize)
                {
                    return false; // below this gameObject
                }
            }
        }
        else // above or to the left of this gameObject
        {
            return false;
        }
        return true; // inside this gameObject
    }
}