/* Author: Derek O Reilly, Dundalk Institute of Technology, Ireland.             */
/* There should always be a javaScript file with the same name as the html file. */
/* This file always holds the playGame function().                               */
/* It also holds game specific code, which will be different for each game       */





/******************** Declare game specific global data and functions *****************/
/* images must be declared as global, so that they will load before the game starts  */

let obstaclesImage = new Image();
obstaclesImage.src = "images/obstacles.png";

let monsterImage = new Image();
monsterImage.src = "images/monster.png";

let bullseyeImage = new Image();
bullseyeImage.src = "images/bullseye.png";

let starsImage = new Image();
starsImage.src = "images/stars.png";

/* Direction that the skeleton is walking */
/* Note that this matches the row in the gameObject image for the given direction */
const UP = 0;
const LEFT = 1;
const DOWN = 2;
const RIGHT = 3;
const STOPPED = 4;
const START = 5;

/* The various gameObjects */
/* These are the positions that each gameObject is held in the gameObjects[] array */
const BACKGROUND = 0;
const OBSTACLES = 1;
const BULLSEYE = 2;
const MONSTER = 3;
const WIN_MESSAGE = 4;

/******************* END OF Declare game specific data and functions *****************/







/* Always have a playGame() function                                     */
/* However, the content of this function will be different for each game */
function playGame()
{
    /* We need to initialise the game objects outside of the Game class */
    /* This function does this initialisation.                          */
    /* This function will:                                              */
    /* 1. create the various game game gameObjects                   */
    /* 2. store the game gameObjects in an array                     */
    /* 3. create a new Game to display the game gameObjects          */
    /* 4. start the Game                                                */


    /* Create the various gameObjects for this game. */
    /* This is game specific code. It will be different for each game, as each game will have it own gameObjects */

    gameObjects[BACKGROUND] = new StaticImage(starsImage, 0, 0, canvas.width, canvas.height);
    gameObjects[OBSTACLES] = new StaticImage(obstaclesImage, 0, 0, canvas.width, canvas.height);
    gameObjects[BULLSEYE] = new Bullseye(bullseyeImage, canvas.width - 50, canvas.height - 50, 50, 50);
    gameObjects[MONSTER] = new Monster(monsterImage);

    /* END OF game specific code. */

    /* Always create a game that uses the gameObject array */
    let game = new MonsterCanvasGame(obstaclesImage);

    /* Always play the game */
    game.start();

    /* If they are needed, then include any game-specific mouse and keyboard listners */
    document.addEventListener('keydown', function (e)
    {
        if (e.keyCode === 37)  // left
        {
            gameObjects[MONSTER].setDirection(LEFT);
        }
        else if (e.keyCode === 38) // up
        {
            gameObjects[MONSTER].setDirection(UP);
        }
        else if (e.keyCode === 39) // right
        {
            gameObjects[MONSTER].setDirection(RIGHT);
        }
        else if (e.keyCode === 40) // down
        {
            gameObjects[MONSTER].setDirection(DOWN);
        }
        else if (e.keyCode === 32) // space
        {
            gameObjects[MONSTER].setDirection(START);
        }
    });

    document.addEventListener('keyup', function (e)
    {
        gameObjects[MONSTER].setDirection(STOPPED);
    });
}